#
# spec file for package sonivox
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soversion 3
Name:           sonivox
Version:        3.6.16
Release:        1.1
Summary:        Fork of the AOSP 'platform_external_sonivox' project
License:        Apache-2.0
URL:            https://github.com/pedrolcl/sonivox
Source:         https://github.com/pedrolcl/sonivox/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake >= 3.14
%if 0%{?suse_version} == 1500
BuildRequires:  gcc13-c++
BuildRequires:  gcc13-PIE
%endif
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  cmake(GTest)

%description
Sonivox is a fork of the Android Open Source Project 'platform_external_sonivox'
including a CMake based build system to be used not on Android, but on any other
Operating System.

This is a Wave Table synthesizer, not using external soundfont files but
embedded samples instead. It is also a real time GM synthesizer.
It may be indicated in projects for small embedded devices. There is neither
MIDI input nor Audio output facilities included in the library. You need to
provide your own input/output.

%package -n libsonivox%{soversion}
Summary:        Fork of the AOSP 'platform_external_sonivox' project

%description -n libsonivox%{soversion}
Sonivox is a fork of the Android Open Source Project 'platform_external_sonivox'
including a CMake based build system to be used not on Android, but on any other
Operating System.

This is a Wave Table synthesizer, not using external soundfont files but
embedded samples instead. It is also a real time GM synthesizer.
It may be indicated in projects for small embedded devices. There is neither
MIDI input nor Audio output facilities included in the library. You need to
provide your own input/output.

%package devel
Summary:        Sonivox library - Development files
Requires:       libsonivox%{soversion} = %{version}

%description devel
Development files for the sonivox library.

%prep
%autosetup -p1

%build
%if 0%{?suse_version} == 1500
export CC=gcc-13 CXX=g++-13
%endif

%cmake -DBUILD_SONIVOX_STATIC:BOOL=FALSE \
       -DBUILD_EXAMPLE:BOOL=FALSE \
       -DBUILD_TESTING:BOOL=FALSE

%cmake_build

%install
%cmake_install

%ldconfig_scriptlets -n libsonivox%{soversion}

%files -n libsonivox%{soversion}
%license LICENSE
%{_libdir}/libsonivox.so.*

%files devel
%{_includedir}/sonivox/
%{_libdir}/cmake/sonivox/
%{_libdir}/libsonivox.so
%{_libdir}/pkgconfig/sonivox.pc

%changelog
* Wed Apr 16 2025 Christophe Marin <christophe@krop.fr>
- Update to 3.6.16
  * Fix bswap use on Android
  * add templates and guidelines
  * Improve test dls downloading
  * Implement a-law/u-law wave format decoding for dls
  * Fix logic error in loop boundary check
  * Addition fix of #37: fix SonivoxTestEnvironment getTmp()
  * Implement WAVE_FORMAT_MPEGLAYER3 decoding for dls
  * Rescue commented logging calls
  * Selectable verbosity level
* Fri Dec 20 2024 Christophe Marin <christophe@krop.fr>
- Update to 3.6.15
  * Add chorus, reverb dry and master gain for sonivoxrender
  * The new host wrapper
  * Implement hwng for macOS and fallback ReadAt for other
    platforms
  * Fix wt_200k_G.c "initializer element is not constant" error
    with GCC < 8.1
- Disable tests. They require downloading a soundfont file from
  a 3rd party website with this release.
* Sun Oct 13 2024 Christophe Marin <christophe@krop.fr>
- Update to 3.6.14
  * Fix CVE-2024-23709
  * Fix "man page for the example program sonivoxrender"
* Mon Jul 24 2023 Christophe Marin <christophe@krop.fr>
- Update to 3.6.12
  * Unleashed function EAS_LoadDLSCollection() to load external
    DLS soundfont files.
* Tue Aug 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Initial package.
